# fba


Tools for feature barcoding analysis

<br>

## Installation

```shell
pip install fba
```

<br>

## Examples

[Cell hashing](https://github.com/jlduan/fba/blob/master/examples/cell_hashing/tutorial.md)

[Cell surface protein labeling](https://github.com/jlduan/fba/blob/master/examples/cell_surface_protein_labeling/tutorial.md)

[CRISPR screening](https://github.com/jlduan/fba/blob/master/examples/crispr_screening/tutorial.md)

[Targeted transcript enrichment](https://github.com/jlduan/fba/blob/master/examples/targeted_transcript_enrichment/tutorial.md)
